load method

  1. @override
Future<Translator> load(
  1. Locale locale
)
override

Start loading the resources for locale. The returned future completes when the resources have finished loading.

It's assumed that this method will return an object that contains a collection of related string resources (typically defined with one method per resource). The object will be retrieved with Localizations.of.

Implementation

@override
Future<Translator> load(Locale locale) async {
  Map<String, dynamic> externalTranslations = {};

  if (this.addTranslations != null) {
    final translations = await this.addTranslations!(locale);
    externalTranslations.addAll(translations);
  }

  final translator = Translator._(
    locale,
    _translationsPath,
    externalTranslations,
  );

  await translator._load();

  return translator;
}